"""
The MkInit Module
=================

A tool to autogenerate explicit top-level imports


+------------------+--------------------------------------------+
| Read the docs    | https://mkinit.readthedocs.io              |
+------------------+--------------------------------------------+
| Github           | https://github.com/Erotemic/mkinit         |
+------------------+--------------------------------------------+
| Pypi             | https://pypi.org/project/mkinit            |
+------------------+--------------------------------------------+

Autogenerates ``__init__.py`` files statically and dynamically.
To use the static version simply pip install and run the ``mkinit`` command with
the directory corresponding to the package.


The main page for this project is: https://github.com/Erotemic/mkinit


Quick Start
-----------

Install mkinit via ``pip install mkinit``. Then run:

.. code:: bash

    MOD_INIT_PATH=path/to/repo/module/__init__.py
    mkinit "$MOD_INIT_PATH"

This will display autogenerated code that exposes all top-level imports.  Use
the ``--diff`` option to check differences with existing code, and add the
``-w`` flag to write the result.

"""

__autogen__ = """
Regenerate Input Command
mkinit ~/code/mkinit/mkinit
"""

__version__ = "1.1.0"

__submodules__ = [
    "dynamic_mkinit",
    "static_mkinit",
]

from mkinit import dynamic_mkinit
from mkinit import static_mkinit

from mkinit.dynamic_mkinit import (
    dynamic_init,
)
from mkinit.static_mkinit import (
    autogen_init,
    static_init,
)

__all__ = [
    "autogen_init",
    "dynamic_init",
    "dynamic_mkinit",
    "static_init",
    "static_mkinit",
]
